"""
Provides Python token classes for the GiPSy scanner.

Library Version 1.1

Copyright 2013 Paul Griffiths
Email: mail@paulgriffiths.net

Distributed under the terms of the GNU General Public License.
http://www.gnu.org/licenses/
"""


from gipsy.token import Token
from gipsy.programtoken import IdentifierToken


class MLStringToken(Token):

    """
    Generic multi-line string token class.
    """

    def __init__(self, value):

        """
        Class initializer.

        Arguments:
        value -- the string to be tokenized.
        """

        Token.__init__(self, value)
        self._token_type_string = "Multi-line String"


class BacktickToken(Token):

    """
    Generic string token class.
    """

    def __init__(self, value):

        """
        Class initializer.

        Arguments:
        value -- the string to be tokenized.
        """

        Token.__init__(self, value)
        self._token_type_string = "Backtick"


class FirstIdentifierToken(IdentifierToken):

    """
    Token class for the first identifier in a qualified
    set, e.g. first.notfirst.stillnotfirst.end.
    """

    def __init__(self, value):

        """
        Class initializer.

        Arguments:
        value -- the string to be tokenized.
        """

        IdentifierToken.__init__(self, value)
        self._token_type_string = "FirstIdentifier"


class DefinitionToken(IdentifierToken):

    """
    Generic definition token class.
    """

    def __init__(self, value):

        """
        Class initializer.

        Arguments:
        value -- the string to be tokenized.
        """

        IdentifierToken.__init__(self, value)
        self._token_type_string = "Definition"


class DecoratorToken(IdentifierToken):

    """
    Generic decorator token class.
    """

    def __init__(self, value):

        """
        Class initializer.

        Arguments:
        value -- the string to be tokenized.
        """

        IdentifierToken.__init__(self, value)
        self._token_type_string = "Decorator"


class BuiltinToken(IdentifierToken):

    """
    Generic built-in token class.
    """

    def __init__(self, value):

        """
        Class initializer.

        Arguments:
        value -- the string to be tokenized.
        """

        IdentifierToken.__init__(self, value)
        self._token_type_string = "Builtin"
