"""
Provides a token list class for the GiPSy scanner.

Library Version 1.1

Copyright 2013 Paul Griffiths
Email: mail@paulgriffiths.net

Distributed under the terms of the GNU General Public License.
http://www.gnu.org/licenses/
"""


class TokenList:

    """
    Class to maintain a list of tokens.

    Instance attributes:
    _tlist -- a Python list containing the tokens.

    Public methods:
    __init__()
    push()
    read()

    """

    def __init__(self):

        """
        Class initializer.
        """

        self._tlist = []

    def push(self, token):

        """
        Pushes a new token onto the top of the list.

        Arguments:
        token -- the new token to push onto the list
        """

        self._tlist.append(token)

    def read(self, decorated=False, html=False, tree=False):

        """
        Returns a string representing the unmodified or modified tokens.

        Arguments:
        decorated -- set to True to decorate with dec_open and dec_close
        html -- set to True to HTML-escape the characters
        tree -- set to True to output in an indented tree view
        """

        out_str = ""
        for token in self._tlist:
            out_str += token.read(decorated=decorated, html=html, tree=tree)
        return out_str
